# Common D-Tools
![CodeQL](https://github.com/M0Rph3U56031769/commondtools/workflows/CodeQL/badge.svg)

![Lines of code](https://img.shields.io/tokei/lines/github/M0Rph3U56031769/commondtools)

![GitHub top language](https://img.shields.io/github/languages/top/M0Rph3U56031769/commondtools)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/M0Rph3U56031769/commondtools)
![GitHub all releases](https://img.shields.io/github/downloads/M0Rph3U56031769/commondtools/total)
![GitHub](https://img.shields.io/github/license/M0Rph3U56031769/commondtools)
![GitHub Repo stars](https://img.shields.io/github/stars/M0Rph3U56031769/commondtools?style=social)
![GitHub watchers](https://img.shields.io/github/watchers/M0Rph3U56031769/commondtools?style=social)
![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/M0Rph3U56031769/commondtools)
![GitHub last commit](https://img.shields.io/github/last-commit/M0Rph3U56031769/commondtools)

![PyPI - Downloads](https://img.shields.io/pypi/dm/commondtools)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/commondtools)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/commondtools)
![PyPI - Format](https://img.shields.io/pypi/format/commondtools)

Hit counters:

![GitHub search hit counter](https://img.shields.io/github/search/M0Rph3U56031769/commondtools/csv)
![GitHub search hit counter](https://img.shields.io/github/search/M0Rph3U56031769/commondtools/commondtools)
![GitHub search hit counter](https://img.shields.io/github/search/M0Rph3U56031769/commondtools/network)


This is a simple package for common usage. 

network, file handling and parallel functions

https://m0rph3u56031769.github.io/commondtools/

https://pypi.org/project/commondtools/

https://github.com/M0Rph3U56031769/commondtools
